@@ -4,7 +4,7 @@
  * Copyright (C) 2014 Eric Wolf
  * This module is free software; it can be used under the terms of the artistic license
  *
- * Version 0.101
+ * Version 0.102
  */
 if( ! $.yote ) { $.yote = {}; }
 $.yote.templates = {
@@ -116,6 +116,7 @@ $.yote.templates = {
 	        recurse = 0;
 	    }
 
+        // function to add to template text before other tag types are processed
 	    if( recurse < 2 && template_txt.indexOf( '<???' ) > -1 ) {
 	        var parts = $.yote.templates._template_parts( template_txt, '???', template_name );
             var A = $.yote.templates._parse_template( parts[ 0 ], template_name, 2 );
@@ -133,6 +134,7 @@ $.yote.templates = {
 	        }
 	    } // ???
 
+        // register controls
 	    if( recurse < 3 && template_txt.indexOf( '<$$$' ) > -1 ) {
 	        var parts = $.yote.templates._template_parts( template_txt, '$$$', template_name );
             var A = $.yote.templates._parse_template( parts[ 0 ], template_name, 3 );
@@ -142,6 +144,7 @@ $.yote.templates = {
             return A;
 	    } // $$$
 
+        // function to add to template text after controls have been registered
         if( recurse < 4 && template_txt.indexOf( '<??' ) > -1 ) {
 	        var parts = $.yote.templates._template_parts( template_txt, '??', template_name );
             var A = $.yote.templates._parse_template( parts[ 0 ], template_name, 4 );
@@ -478,7 +481,16 @@ $.yote.templates = {
 		         txt.substring( start + len, end ).trim(),
 		         txt.substring( end+len ) ];
     }, //_template_parts
-
+    
+    // pass in a value/variable (calling this vavar) name string, a context and a boolean.
+    // if the boolean is false, then if the vavar name is not defined in the context, it is returned literally
+    // so   _parse_val( "FOO", { context object with foo defined as "bar" }, true ) --> "bar"
+    // so   _parse_val( "FOO", { context object with NOT foo defined }, true ) --> "FOO"
+    // in addition, the vavar contains period characters, those are treated as separators.
+    //      _parse_val( "foo.bar.baz", { context object with foo object that has a bar object that has a baz field with the value of "yup" } ) --> "yup"
+    // if the vavar contains a @ glyph, those are used to indicate that the final value is a list
+    // if the vavar contains a @ or % glyph, those are used to indicate that the final value is a hash
+    //    if a list or hash is the final value, then a 'wrapped' version of that datastructure is returned. The wrapping allows for pagination.
     _parse_val:function( value, context, no_literal ) {
 	    var tlist = value.trim().split(/[\.]/);
 	    var subj = context;
@@ -530,38 +542,25 @@ $.yote.templates = {
           <$$$ set varname value $$$>
           <$$$ control ctlname <..html control..> $$$>
         */
-	    var parts   = args_string.match( /^\s*(\S+)\s+(\S+)\s+(\S[\s\S]*)?/ );
-	    var cmd     = parts ? parts[ 1 ] : undefined;
-	    var varname = parts ? parts[ 2 ] : undefined;
-	    var rest    = parts ? parts[ 3 ] : undefined;
-	    if( cmd == 'set' ) {
-	        if( rest.match( /^function[ \(]/ ) ) {
-		        var fun = eval( '[' + rest + ']' )[ 0 ];
-		        try { 
-		            context.set( varname, fun( context ) );
-		        } catch( Err ) {
-		            console.log( "Error in after render function '" + ctx.template_path + "' in function '" + f + "' : " + Err);
-		        }
-	        }
-	        else {
-		        var args = $.yote.templates._parse_args( rest );
-		        var val = context.parse( args[ 0 ], true );
-		        context.set( varname, val );
-	        }
+	    var parts   = args_string.match( /^\s*(\S+)(\s+\S[\s\S]*)?/ );
+	    var varname = parts ? parts[ 1 ] : undefined;
+	    var rest    = parts ? parts[ 2 ] : undefined;
+
+        // check to see if the control already has an id or not.
+        // assign an id if it does not.
+	    var ctrl_parts = /\*\<[\s\S]* id\s*=\s*['"]?(\S+)['"]? /.exec( rest );
+	    var ctrl_id;
+	    if( ctrl_parts ) {
+		    ctrl_id = ctrl_parts[ 1 ];
 	    }
-	    else if( cmd == 'control' ) {
-	        var ctrl_parts = /\*\<[\s\S]* id\s*=\s*['"]?(\S+)['"]? /.exec( rest );
-	        var ctrl_id;
-	        if( ctrl_parts ) {
-		        ctrl_id = ctrl_parts[ 1 ];
-	        }
-	        else {
-		        ctrl_id = $.yote._next_id();
+	    else {
+		    ctrl_id = $.yote._next_id();
+            if( rest )
 		        rest = rest.replace( /^\s*(<\s*[^\s\>]+)([ \>])/, '$1 id="' + ctrl_id + '" $2' );
-	        }
-	        context.controls[ varname ] = '#' + ctrl_id;
-	        return rest;
-        } //has parts
+        }
+	    context.controls[ varname ] = '#' + ctrl_id;
+	    return rest;
+
         return '';
 
     }, //_register
